==> haskell-djot-0.1.1.3-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-djot.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 djot
version:              0.1.1.3
visibility:           public
id:                   djot-0.1.1.3-KRWgWfRtLVR77ZsqYbGK3E
key:                  djot-0.1.1.3-KRWgWfRtLVR77ZsqYbGK3E
license:              MIT
copyright:            Copyright (C) 2024 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Parser and renderer for djot light markup syntax.
description:
    Djot (<https://djot.net>) is a light markup language.
    This package provides a data structure to represent
    djot documents, a very fast parser, and functions
    to render a parsed document as HTML and as djot.

category:             Text
abi:                  1d2a6552e5636225639f2710246c8c1b
exposed:              True
exposed-modules:
    Djot Djot.AST Djot.Attributes Djot.Blocks Djot.Djot Djot.Html
    Djot.Inlines Djot.Options Djot.Parse

import-dirs:          /usr/lib/ghc-9.2.8/site-local/djot-0.1.1.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/djot-0.1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-djot
hs-libraries:         HSdjot-0.1.1.3-KRWgWfRtLVR77ZsqYbGK3E
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    doclayout-0.4.0.1-E6LkfmFLOSII7lveN7V730 mtl-2.2.2 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-djot/html/djot.haddock
haddock-html:         /usr/share/doc/haskell-djot/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-djot-0.1.1.3-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-djot.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 djot
version:              0.1.1.3
visibility:           public
id:                   djot-0.1.1.3-8crgLE44s0c3noBYWPmLEo
key:                  djot-0.1.1.3-8crgLE44s0c3noBYWPmLEo
license:              MIT
copyright:            Copyright (C) 2024 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Parser and renderer for djot light markup syntax.
description:
    Djot (<https://djot.net>) is a light markup language.
    This package provides a data structure to represent
    djot documents, a very fast parser, and functions
    to render a parsed document as HTML and as djot.

category:             Text
abi:                  70587f21d9e329e55e21dd13a778a9e1
exposed:              True
exposed-modules:
    Djot Djot.AST Djot.Attributes Djot.Blocks Djot.Djot Djot.Html
    Djot.Inlines Djot.Options Djot.Parse

import-dirs:          /usr/lib/ghc-9.2.8/site-local/djot-0.1.1.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/djot-0.1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-djot
hs-libraries:         HSdjot-0.1.1.3-8crgLE44s0c3noBYWPmLEo
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    doclayout-0.4.0.1-DOBWBghElu488UW1QaF49w mtl-2.2.2 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-djot/html/djot.haddock
haddock-html:         /usr/share/doc/haskell-djot/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
